# Generated by roxygen2: do not edit by hand

S3method(plot,tidylearn_eda)
S3method(plot,tidylearn_model)
S3method(predict,tidylearn_model)
S3method(predict,tidylearn_stratified)
S3method(predict,tidylearn_transfer)
S3method(print,tidy_apriori)
S3method(print,tidy_dbscan)
S3method(print,tidy_gap)
S3method(print,tidy_hclust)
S3method(print,tidy_kmeans)
S3method(print,tidy_mds)
S3method(print,tidy_pam)
S3method(print,tidy_pca)
S3method(print,tidy_silhouette)
S3method(print,tidylearn_automl)
S3method(print,tidylearn_compute_advice)
S3method(print,tidylearn_data)
S3method(print,tidylearn_eda)
S3method(print,tidylearn_gpu_check)
S3method(print,tidylearn_model)
S3method(print,tidylearn_pipeline)
S3method(summary,tidylearn_model)
S3method(summary,tidylearn_pipeline)
S3method(tl_compute_advisor,character)
S3method(tl_compute_advisor,default)
S3method(tl_compute_advisor,tidylearn_supervised)
export("%>%")
export(augment_dbscan)
export(augment_hclust)
export(augment_kmeans)
export(augment_pam)
export(augment_pca)
export(calc_validation_metrics)
export(calc_wss)
export(compare_clusterings)
export(compare_distances)
export(create_cluster_dashboard)
export(explore_dbscan_params)
export(filter_rules_by_item)
export(find_related_items)
export(get_pca_loadings)
export(get_pca_variance)
export(inspect_rules)
export(optimal_clusters)
export(optimal_hclust_k)
export(plot_cluster_comparison)
export(plot_cluster_sizes)
export(plot_clusters)
export(plot_dendrogram)
export(plot_distance_heatmap)
export(plot_elbow)
export(plot_gap_stat)
export(plot_knn_dist)
export(plot_mds)
export(plot_silhouette)
export(plot_variance_explained)
export(recommend_products)
export(standardize_data)
export(suggest_eps)
export(summarize_rules)
export(tidy_apriori)
export(tidy_clara)
export(tidy_cutree)
export(tidy_dbscan)
export(tidy_dendrogram)
export(tidy_dist)
export(tidy_gap_stat)
export(tidy_gower)
export(tidy_hclust)
export(tidy_kmeans)
export(tidy_knn_dist)
export(tidy_mds)
export(tidy_mds_classical)
export(tidy_mds_kruskal)
export(tidy_mds_sammon)
export(tidy_mds_smacof)
export(tidy_pam)
export(tidy_pca)
export(tidy_pca_biplot)
export(tidy_pca_screeplot)
export(tidy_rules)
export(tidy_silhouette)
export(tidy_silhouette_analysis)
export(tl_add_cluster_features)
export(tl_anomaly_aware)
export(tl_auto_interactions)
export(tl_auto_ml)
export(tl_calc_classification_metrics)
export(tl_check_assumptions)
export(tl_check_gpu)
export(tl_cloud_allow_host)
export(tl_cloud_allowed_hosts)
export(tl_cloud_consent)
export(tl_cloud_jobs)
export(tl_compare_cv)
export(tl_compare_pipeline_models)
export(tl_compute_advisor)
export(tl_cv)
export(tl_dashboard)
export(tl_default_param_grid)
export(tl_detect_outliers)
export(tl_diagnostic_dashboard)
export(tl_evaluate)
export(tl_explore)
export(tl_get_best_model)
export(tl_influence_measures)
export(tl_interaction_effects)
export(tl_load_pipeline)
export(tl_model)
export(tl_pipeline)
export(tl_plot_cv_comparison)
export(tl_plot_cv_results)
export(tl_plot_deep_architecture)
export(tl_plot_deep_history)
export(tl_plot_gain)
export(tl_plot_importance_comparison)
export(tl_plot_importance_regularized)
export(tl_plot_influence)
export(tl_plot_interaction)
export(tl_plot_intervals)
export(tl_plot_lift)
export(tl_plot_model_comparison)
export(tl_plot_nn_architecture)
export(tl_plot_nn_tuning)
export(tl_plot_partial_dependence)
export(tl_plot_regularization_cv)
export(tl_plot_regularization_path)
export(tl_plot_svm_boundary)
export(tl_plot_svm_tuning)
export(tl_plot_tree)
export(tl_plot_tuning_results)
export(tl_plot_xgboost_importance)
export(tl_plot_xgboost_shap_dependence)
export(tl_plot_xgboost_shap_summary)
export(tl_plot_xgboost_tree)
export(tl_predict_pipeline)
export(tl_prepare_data)
export(tl_read)
export(tl_read_bigquery)
export(tl_read_csv)
export(tl_read_db)
export(tl_read_dir)
export(tl_read_excel)
export(tl_read_github)
export(tl_read_json)
export(tl_read_kaggle)
export(tl_read_mysql)
export(tl_read_parquet)
export(tl_read_postgres)
export(tl_read_rdata)
export(tl_read_rds)
export(tl_read_s3)
export(tl_read_sqlite)
export(tl_read_tsv)
export(tl_read_zip)
export(tl_reduce_dimensions)
export(tl_run_pipeline)
export(tl_save_pipeline)
export(tl_semisupervised)
export(tl_split)
export(tl_step_selection)
export(tl_stratified_models)
export(tl_table)
export(tl_table_clusters)
export(tl_table_coefficients)
export(tl_table_comparison)
export(tl_table_confusion)
export(tl_table_importance)
export(tl_table_loadings)
export(tl_table_metrics)
export(tl_table_variance)
export(tl_test_interactions)
export(tl_test_model_difference)
export(tl_transfer_learning)
export(tl_tune_deep)
export(tl_tune_grid)
export(tl_tune_nn)
export(tl_tune_random)
export(tl_tune_xgboost)
export(tl_version)
export(tl_xgboost_shap)
export(visualize_rules)
importFrom(ROCR,performance)
importFrom(ROCR,prediction)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,summarize)
importFrom(dplyr,tibble)
importFrom(e1071,svm)
importFrom(e1071,tune)
importFrom(gbm,gbm)
importFrom(gbm,predict.gbm)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_contour)
importFrom(ggplot2,geom_density)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_jitter)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_gradient)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_fill_gradient2)
importFrom(ggplot2,scale_x_log10)
importFrom(ggplot2,stat_qq)
importFrom(ggplot2,stat_qq_line)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,theme_void)
importFrom(glmnet,cv.glmnet)
importFrom(glmnet,glmnet)
importFrom(glmnet,predict.glmnet)
importFrom(magrittr,"%>%")
importFrom(nnet,nnet)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map_dbl)
importFrom(purrr,map_lgl)
importFrom(randomForest,importance)
importFrom(randomForest,randomForest)
importFrom(rlang,.data)
importFrom(rlang,.env)
importFrom(rpart,rpart)
importFrom(rpart,rpart.control)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,anova)
importFrom(stats,aov)
importFrom(stats,as.formula)
importFrom(stats,bartlett.test)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,cooks.distance)
importFrom(stats,cor)
importFrom(stats,dfbetas)
importFrom(stats,dffits)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,glm)
importFrom(stats,hatvalues)
importFrom(stats,influence.measures)
importFrom(stats,kruskal.test)
importFrom(stats,lm)
importFrom(stats,lm.influence)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,p.adjust)
importFrom(stats,poly)
importFrom(stats,predict)
importFrom(stats,qqnorm)
importFrom(stats,reorder)
importFrom(stats,residuals)
importFrom(stats,rstandard)
importFrom(stats,rstudent)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,shapiro.test)
importFrom(stats,step)
importFrom(stats,t.test)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,var)
importFrom(stats,wilcox.test)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,crossing)
importFrom(tidyr,nest)
importFrom(tidyr,unnest)
importFrom(utils,combn)
importFrom(utils,getFromNamespace)
importFrom(utils,head)
importFrom(utils,packageVersion)
importFrom(yardstick,accuracy)
importFrom(yardstick,f_meas)
importFrom(yardstick,mae)
importFrom(yardstick,mape)
importFrom(yardstick,pr_auc)
importFrom(yardstick,precision)
importFrom(yardstick,recall)
importFrom(yardstick,rmse)
importFrom(yardstick,roc_auc)
importFrom(yardstick,rsq)
