% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-deep-learning.R
\name{tl_plot_deep_architecture}
\alias{tl_plot_deep_architecture}
\title{Plot deep learning model architecture}
\usage{
tl_plot_deep_architecture(model, ...)
}
\arguments{
\item{model}{A tidylearn deep learning model object}

\item{...}{Additional arguments}
}
\value{
The return value of \code{keras::plot_model()}, an architecture
diagram of the Keras model.
}
\description{
Plot deep learning model architecture
}
\examples{
\dontrun{
if (requireNamespace("keras", quietly = TRUE)) {
  model <- tl_model(iris, Species ~ ., method = "deep", epochs = 5)
  tl_plot_deep_architecture(model)
}
}
}
