% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-svm.R
\name{tidylearn-svm}
\alias{tidylearn-svm}
\title{Support Vector Machines for tidylearn}
\description{
SVM functionality for classification and
regression
}
