% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-xgboost.R
\name{tl_plot_xgboost_shap_dependence}
\alias{tl_plot_xgboost_shap_dependence}
\title{Plot SHAP dependence for a specific feature}
\usage{
tl_plot_xgboost_shap_dependence(
  model,
  feature,
  interaction_feature = NULL,
  data = NULL,
  n_samples = 100
)
}
\arguments{
\item{model}{A tidylearn XGBoost model object}

\item{feature}{Feature name to plot}

\item{interaction_feature}{Feature to use for coloring (default: NULL)}

\item{data}{Data for SHAP value calculation
(default: NULL, uses training data)}

\item{n_samples}{Number of samples to use
(default: 100, NULL for all)}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot SHAP dependence for a specific feature
}
