% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pipeline.R
\name{summary.tidylearn_pipeline}
\alias{summary.tidylearn_pipeline}
\title{Summarize a tidylearn pipeline}
\usage{
\method{summary}{tidylearn_pipeline}(object, ...)
}
\arguments{
\item{object}{A tidylearn pipeline object}

\item{...}{Additional arguments (not used)}
}
\value{
The input pipeline \code{object}, returned invisibly. Called
for its side effect of printing detailed pipeline and model results.
}
\description{
Summarize a tidylearn pipeline
}
\examples{
\donttest{
pipe <- tl_pipeline(iris, Species ~ .)
summary(pipe)
}
}
