% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-mds.R
\name{plot_mds}
\alias{plot_mds}
\title{Plot MDS Configuration}
\usage{
plot_mds(mds_obj, color_by = NULL, label_points = TRUE, dim_x = 1, dim_y = 2)
}
\arguments{
\item{mds_obj}{A tidy_mds object}

\item{color_by}{Optional variable to color points by}

\item{label_points}{Logical; add point labels? (default: TRUE)}

\item{dim_x}{Which dimension for x-axis (default: 1)}

\item{dim_y}{Which dimension for y-axis (default: 2)}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Visualize MDS results
}
\examples{
\donttest{
mds <- tidy_mds(USArrests, method = "classical")
plot_mds(mds)
}

}
