% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-hclust.R
\name{print.tidy_hclust}
\alias{print.tidy_hclust}
\title{Print Method for tidy_hclust}
\usage{
\method{print}{tidy_hclust}(x, ...)
}
\arguments{
\item{x}{A tidy_hclust object}

\item{...}{Additional arguments (ignored)}
}
\value{
The input object \code{x}, returned invisibly.
}
\description{
Print Method for tidy_hclust
}
\examples{
\donttest{
hc <- tidy_hclust(USArrests, method = "ward.D2")
print(hc)
}

}
