% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-market-basket.R
\name{print.tidy_apriori}
\alias{print.tidy_apriori}
\title{Print Method for tidy_apriori}
\usage{
\method{print}{tidy_apriori}(x, ...)
}
\arguments{
\item{x}{A tidy_apriori object}

\item{...}{Additional arguments (ignored)}
}
\value{
The input object \code{x}, returned invisibly.
}
\description{
Print Method for tidy_apriori
}
\examples{
\donttest{
if (requireNamespace("arules", quietly = TRUE)) {
  data("Groceries", package = "arules")
  res <- tidy_apriori(Groceries, support = 0.001, confidence = 0.5)
  print(res)
}
}

}
