% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-classification.R
\name{tl_fit_logistic}
\alias{tl_fit_logistic}
\title{Fit a logistic regression model}
\usage{
tl_fit_logistic(data, formula, ...)
}
\arguments{
\item{data}{A data frame containing the training data}

\item{formula}{A formula specifying the model}

\item{...}{Additional arguments to pass to glm()}
}
\value{
A fitted logistic regression model
}
\description{
Fit a logistic regression model
}
\keyword{internal}
