% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-dbscan.R
\name{augment_dbscan}
\alias{augment_dbscan}
\title{Augment Data with DBSCAN Cluster Assignments}
\usage{
augment_dbscan(dbscan_obj, data)
}
\arguments{
\item{dbscan_obj}{A tidy_dbscan object}

\item{data}{Original data frame}
}
\value{
A tibble containing the original \code{data} with additional columns
\code{cluster} (factor), \code{is_noise} (logical), and \code{is_core}
(logical).
}
\description{
Augment Data with DBSCAN Cluster Assignments
}
\examples{
\donttest{
db <- tidy_dbscan(iris[, 1:4], eps = 0.5, minPts = 5)
augmented <- augment_dbscan(db, iris)
}

}
