% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/model-selection.R
\name{tidylearn-model-selection}
\alias{tidylearn-model-selection}
\title{Model Selection Functions for tidylearn}
\description{
Functions for stepwise model selection,
cross-validation, and hyperparameter tuning
}
