% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-pca.R
\name{get_pca_variance}
\alias{get_pca_variance}
\title{Get Variance Explained Summary}
\usage{
get_pca_variance(pca_obj)
}
\arguments{
\item{pca_obj}{A tidy_pca object}
}
\value{
A tibble with columns \code{component}, \code{sdev},
\code{variance}, \code{prop_variance}, and \code{cum_variance}.
}
\description{
Get Variance Explained Summary
}
\examples{
\donttest{
pca <- tidy_pca(USArrests)
get_pca_variance(pca)
}

}
