% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core.R
\name{print.tidylearn_model}
\alias{print.tidylearn_model}
\title{Print method for tidylearn models}
\usage{
\method{print}{tidylearn_model}(x, ...)
}
\arguments{
\item{x}{A tidylearn model object}

\item{...}{Additional arguments (ignored)}
}
\value{
The input object \code{x}, returned invisibly.
}
\description{
Print method for tidylearn models
}
\examples{
\donttest{
model <- tl_model(mtcars, mpg ~ wt + hp, method = "linear")
print(model)
}
}
