% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pipeline.R
\name{tl_save_pipeline}
\alias{tl_save_pipeline}
\title{Save a pipeline to disk}
\usage{
tl_save_pipeline(pipeline, file)
}
\arguments{
\item{pipeline}{A tidylearn pipeline object}

\item{file}{Path to save the pipeline}
}
\value{
Called for its side effect of saving to disk; returns
\code{NULL} invisibly.
}
\description{
Save a pipeline to disk
}
\examples{
\donttest{
pipe <- tl_pipeline(iris, Species ~ .)
tl_save_pipeline(pipe, tempfile(fileext = ".rds"))
}
}
