% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-neural-networks.R
\name{tl_plot_nn_architecture}
\alias{tl_plot_nn_architecture}
\title{Plot neural network architecture}
\usage{
tl_plot_nn_architecture(model, ...)
}
\arguments{
\item{model}{A tidylearn neural network model object}

\item{...}{Additional arguments}
}
\value{
The return value of \code{\link[NeuralNetTools]{plotnet}}, called for
its side effect of drawing the network diagram, or \code{NULL} if the
\pkg{NeuralNetTools} package is not installed.
}
\description{
Plot neural network architecture
}
\examples{
\donttest{
if (requireNamespace("NeuralNetTools", quietly = TRUE)) {
  model <- tl_model(iris, Species ~ ., method = "nn", size = 3)
  tl_plot_nn_architecture(model)
}
}
}
