% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-mds.R
\name{tidy_mds_kruskal}
\alias{tidy_mds_kruskal}
\title{Kruskal's Non-metric MDS}
\usage{
tidy_mds_kruskal(dist_mat, ndim = 2, ...)
}
\arguments{
\item{dist_mat}{A distance matrix (dist object)}

\item{ndim}{Number of dimensions (default: 2)}

\item{...}{Additional arguments passed to MASS::isoMDS()}
}
\value{
A list of class \code{"tidy_mds"} containing:
\itemize{
\item config: tibble of MDS coordinates
\item stress: Kruskal stress value
\item method: \code{"Kruskal's isoMDS"}
\item model: the \code{\link[MASS]{isoMDS}} result
}
}
\description{
Performs Kruskal's isoMDS
}
\examples{
\donttest{
d <- dist(USArrests)
mds <- tidy_mds_kruskal(d)
}

}
