% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-clustering.R
\name{augment_kmeans}
\alias{augment_kmeans}
\title{Augment Data with K-Means Cluster Assignments}
\usage{
augment_kmeans(kmeans_obj, data)
}
\arguments{
\item{kmeans_obj}{A tidy_kmeans object}

\item{data}{Original data frame}
}
\value{
A tibble containing the original \code{data} with an additional
\code{cluster} factor column indicating cluster assignments.
}
\description{
Augment Data with K-Means Cluster Assignments
}
\examples{
\donttest{
km <- tidy_kmeans(iris[, 1:4], k = 3)
augmented <- augment_kmeans(km, iris)
}

}
