% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-svm.R
\name{tl_predict_svm}
\alias{tl_predict_svm}
\title{Predict using a support vector machine model}
\usage{
tl_predict_svm(model, new_data, type = "response", ...)
}
\arguments{
\item{model}{A tidylearn SVM model object}

\item{new_data}{A data frame containing the new data}

\item{type}{Type of prediction: "response" (default),
"prob" (for classification)}

\item{...}{Additional arguments}
}
\value{
Predictions
}
\description{
Predict using a support vector machine model
}
\keyword{internal}
