% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read.R
\name{tl_read_parquet}
\alias{tl_read_parquet}
\title{Read a Parquet file}
\usage{
tl_read_parquet(path, ...)
}
\arguments{
\item{path}{Path to a Parquet file.}

\item{...}{Additional arguments passed to \code{nanoparquet::read_parquet()}.}
}
\value{
A \code{tidylearn_data} object (a \link[tibble]{tibble} subclass)
with attributes \code{tl_source}, \code{tl_format}, and
\code{tl_timestamp}.
}
\description{
Reads a Parquet file into a \code{tidylearn_data} object. Requires the
\pkg{nanoparquet} package.
}
\examples{
\donttest{
# data <- tl_read_parquet("path/to/data.parquet")
}

}
