% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core.R
\name{tl_version}
\alias{tl_version}
\title{Get tidylearn version information}
\usage{
tl_version()
}
\value{
A package_version object containing the version number
}
\description{
Get tidylearn version information
}
\examples{
tl_version()
}
