% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-regression.R
\name{tl_plot_diagnostics}
\alias{tl_plot_diagnostics}
\title{Plot diagnostics for a regression model}
\usage{
tl_plot_diagnostics(model, which = 1:4, ...)
}
\arguments{
\item{model}{A tidylearn regression model object}

\item{which}{Which plots to create (1:4)}

\item{...}{Additional arguments}
}
\value{
A ggplot object (or list of ggplot objects)
}
\description{
Plot diagnostics for a regression model
}
\keyword{internal}
