% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-xgboost.R
\name{tidylearn-xgboost}
\alias{tidylearn-xgboost}
\title{XGBoost Functions for tidylearn}
\description{
XGBoost-specific implementation for gradient boosting
}
