% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-trees.R
\name{tl_plot_importance}
\alias{tl_plot_importance}
\title{Plot variable importance for tree-based models}
\usage{
tl_plot_importance(model, top_n = 20, ...)
}
\arguments{
\item{model}{A tidylearn tree-based model object}

\item{top_n}{Number of top features to display (default: 20)}

\item{...}{Additional arguments}
}
\value{
A ggplot object
}
\description{
Plot variable importance for tree-based models
}
\keyword{internal}
