% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-validation.R
\name{print.tidy_gap}
\alias{print.tidy_gap}
\title{Print Method for tidy_gap}
\usage{
\method{print}{tidy_gap}(x, ...)
}
\arguments{
\item{x}{A tidy_gap object}

\item{...}{Additional arguments (ignored)}
}
\value{
The input object \code{x}, returned invisibly.
}
\description{
Print Method for tidy_gap
}
\examples{
\donttest{
gap <- tidy_gap_stat(iris[, 1:4], max_k = 6, B = 10)
print(gap)
}

}
