% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-neural-networks.R
\name{tl_plot_nn_tuning}
\alias{tl_plot_nn_tuning}
\title{Plot neural network training history}
\usage{
tl_plot_nn_tuning(model, ...)
}
\arguments{
\item{model}{A tidylearn neural network model object}

\item{...}{Additional arguments}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot neural network training history
}
