% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-trees.R
\name{tl_predict_boost}
\alias{tl_predict_boost}
\title{Predict using a gradient boosting model}
\usage{
tl_predict_boost(model, new_data, type = "response", n.trees = NULL, ...)
}
\arguments{
\item{model}{A tidylearn boost model object}

\item{new_data}{A data frame containing the new data}

\item{type}{Type of prediction: "response"
(default), "prob" (for classification)}

\item{n.trees}{Number of trees to use for prediction
(if NULL, uses optimal number)}

\item{...}{Additional arguments}
}
\value{
Predictions
}
\description{
Predict using a gradient boosting model
}
\keyword{internal}
