% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pipeline.R
\name{tl_predict_pipeline}
\alias{tl_predict_pipeline}
\title{Make predictions using a pipeline}
\usage{
tl_predict_pipeline(
  pipeline,
  new_data,
  type = "response",
  model_name = NULL,
  ...
)
}
\arguments{
\item{pipeline}{A tidylearn pipeline object with results}

\item{new_data}{A data frame containing the new data}

\item{type}{Type of prediction (default: "response")}

\item{model_name}{Name of model to use (if NULL, uses the best model)}

\item{...}{Additional arguments passed to predict}
}
\value{
A \link[tibble]{tibble} with a \code{.pred} column containing
predictions from the selected (or best) pipeline model, after
applying the same preprocessing steps used during training.
}
\description{
Make predictions using a pipeline
}
