% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualization.R
\name{tl_plot_cv_results}
\alias{tl_plot_cv_results}
\title{Plot cross-validation results}
\usage{
tl_plot_cv_results(cv_results, metrics = NULL)
}
\arguments{
\item{cv_results}{Cross-validation results from tl_cv function}

\item{metrics}{Character vector of metrics to plot
(if NULL, plots all metrics)}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot cross-validation results
}
