% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-market-basket.R
\name{summarize_rules}
\alias{summarize_rules}
\title{Summarize Association Rules}
\usage{
summarize_rules(rules_obj)
}
\arguments{
\item{rules_obj}{A tidy_apriori object or rules tibble}
}
\value{
A list with \code{n_rules} and summary statistics (\code{min},
\code{max}, \code{mean}, \code{median}) for \code{support},
\code{confidence}, and \code{lift}.
}
\description{
Get summary statistics about rules
}
\examples{
\donttest{
if (requireNamespace("arules", quietly = TRUE)) {
  data("Groceries", package = "arules")
  res <- tidy_apriori(Groceries, support = 0.001, confidence = 0.5)
  summarize_rules(res)
}
}

}
