% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metrics.R
\name{tl_evaluate_thresholds}
\alias{tl_evaluate_thresholds}
\title{Evaluate metrics at different thresholds}
\usage{
tl_evaluate_thresholds(actuals, probs, thresholds, pos_class)
}
\arguments{
\item{actuals}{Actual values (ground truth)}

\item{probs}{Predicted probabilities}

\item{thresholds}{Vector of thresholds to evaluate}

\item{pos_class}{The positive class}
}
\value{
A tibble of metrics at different thresholds
}
\description{
Evaluate metrics at different thresholds
}
\keyword{internal}
