% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tuning.R
\name{tidylearn-tuning}
\alias{tidylearn-tuning}
\title{Hyperparameter Tuning Functions for tidylearn}
\description{
Functions for automatic hyperparameter tuning and selection
}
