% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metrics.R
\name{tl_calculate_pr_auc}
\alias{tl_calculate_pr_auc}
\title{Calculate the area under the precision-recall curve}
\usage{
tl_calculate_pr_auc(perf)
}
\arguments{
\item{perf}{A ROCR performance object}
}
\value{
The area under the PR curve
}
\description{
Calculate the area under the precision-recall curve
}
\keyword{internal}
