% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-trees.R
\name{tl_plot_tree}
\alias{tl_plot_tree}
\title{Plot a decision tree}
\usage{
tl_plot_tree(model, ...)
}
\arguments{
\item{model}{A tidylearn tree model object}

\item{...}{Additional arguments to pass to rpart.plot()}
}
\value{
The return value of \code{\link[rpart.plot]{rpart.plot}}, called
for its side effect of drawing the tree.
}
\description{
Plot a decision tree
}
\examples{
\donttest{
model <- tl_model(iris, Species ~ ., method = "tree")
tl_plot_tree(model)
}
}
