% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pipeline.R
\name{print.tidylearn_pipeline}
\alias{print.tidylearn_pipeline}
\title{Print a tidylearn pipeline}
\usage{
\method{print}{tidylearn_pipeline}(x, ...)
}
\arguments{
\item{x}{A tidylearn pipeline object}

\item{...}{Additional arguments (not used)}
}
\value{
The input pipeline object \code{x}, returned invisibly.
}
\description{
Print a tidylearn pipeline
}
\examples{
\donttest{
pipe <- tl_pipeline(iris, Species ~ .)
print(pipe)
}
}
