% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualization.R
\name{tl_plot_model_comparison}
\alias{tl_plot_model_comparison}
\title{Plot model comparison}
\usage{
tl_plot_model_comparison(..., new_data = NULL, metrics = NULL, names = NULL)
}
\arguments{
\item{...}{tidylearn model objects to compare}

\item{new_data}{Optional data frame for evaluation
(if NULL, uses training data)}

\item{metrics}{Character vector of metrics to compute}

\item{names}{Optional character vector of model names}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot model comparison
}
\examples{
\donttest{
m1 <- tl_model(mtcars, mpg ~ wt + hp, method = "linear")
m2 <- tl_model(mtcars, mpg ~ wt + hp, method = "lasso")
tl_plot_model_comparison(m1, m2, names = c("Linear", "Lasso"))
}
}
