% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-regression.R
\name{tidylearn-regression}
\alias{tidylearn-regression}
\title{Regression Functions for tidylearn}
\description{
Linear and polynomial regression functionality
}
