% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-classification.R
\name{tidylearn-classification}
\alias{tidylearn-classification}
\title{Classification Functions for tidylearn}
\description{
Logistic regression and classification metrics functionality
}
