% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-dbscan.R
\name{plot_knn_dist}
\alias{plot_knn_dist}
\title{Plot k-NN Distance Plot}
\usage{
plot_knn_dist(data, k = 4, add_suggestion = TRUE, percentile = 0.95)
}
\arguments{
\item{data}{A data frame or tidy_knn_dist result}

\item{k}{If data is a data frame, k for k-NN (default: 4)}

\item{add_suggestion}{Add suggested eps line? (default: TRUE)}

\item{percentile}{Percentile for suggestion (default: 0.95)}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Visualize k-NN distances to help choose eps
}
\examples{
\donttest{
plot_knn_dist(iris[, 1:4], k = 5)
}

}
