% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-validation.R
\name{plot_silhouette}
\alias{plot_silhouette}
\title{Plot Silhouette Analysis}
\usage{
plot_silhouette(sil_obj)
}
\arguments{
\item{sil_obj}{A tidy_silhouette object or tibble
from tidy_silhouette_analysis}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot Silhouette Analysis
}
\examples{
\donttest{
km <- kmeans(iris[, 1:4], centers = 3, nstart = 25)
d <- dist(iris[, 1:4])
sil <- tidy_silhouette(km$cluster, d)
plot_silhouette(sil)
}

}
