% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-xgboost.R
\name{tl_plot_xgboost_shap_summary}
\alias{tl_plot_xgboost_shap_summary}
\title{Plot SHAP summary for XGBoost model}
\usage{
tl_plot_xgboost_shap_summary(model, data = NULL, top_n = 10, n_samples = 100)
}
\arguments{
\item{model}{A tidylearn XGBoost model object}

\item{data}{Data for SHAP value calculation
(default: NULL, uses training data)}

\item{top_n}{Number of top features to display (default: 10)}

\item{n_samples}{Number of samples to use
(default: 100, NULL for all)}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot SHAP summary for XGBoost model
}
\examples{
\donttest{
if (requireNamespace("xgboost", quietly = TRUE)) {
  model <- tl_model(mtcars, mpg ~ ., method = "xgboost")
  tl_plot_xgboost_shap_summary(model, n_samples = 20)
}
}
}
