% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pipeline.R
\name{tl_pipeline}
\alias{tl_pipeline}
\title{Create a modeling pipeline}
\usage{
tl_pipeline(
  data,
  formula,
  preprocessing = NULL,
  models = NULL,
  evaluation = NULL,
  ...
)
}
\arguments{
\item{data}{A data frame containing the data}

\item{formula}{A formula specifying the model}

\item{preprocessing}{A list of preprocessing steps}

\item{models}{A list of models to train}

\item{evaluation}{A list of evaluation criteria}

\item{...}{Additional arguments}
}
\value{
A \code{tidylearn_pipeline} object (S3 list) with components
\code{$formula}, \code{$data}, \code{$preprocessing},
\code{$models}, \code{$evaluation}, and \code{$results}
(initially \code{NULL}; populated after \code{\link{tl_run_pipeline}}).
}
\description{
Create a modeling pipeline
}
\examples{
\donttest{
pipe <- tl_pipeline(iris, Species ~ .,
  models = list(tree = list(method = "tree")))
print(pipe)
}
}
