% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-distance.R
\name{tidy_dist}
\alias{tidy_dist}
\title{Tidy Distance Matrix Computation}
\usage{
tidy_dist(data, method = "euclidean", cols = NULL, ...)
}
\arguments{
\item{data}{A data frame or tibble}

\item{method}{Character; distance method
(default: "euclidean"). Options: "euclidean",
"manhattan", "maximum", "gower"}

\item{cols}{Columns to include (tidy select).
If NULL, uses all numeric columns.}

\item{...}{Additional arguments passed to distance functions}
}
\value{
A \code{\link[stats]{dist}} object containing the computed
distance matrix.
}
\description{
Compute distance matrices with tidy output
}
\examples{
\donttest{
d <- tidy_dist(iris[, 1:4], method = "euclidean")
}

}
