% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-xgboost.R
\name{tl_plot_xgboost_importance}
\alias{tl_plot_xgboost_importance}
\title{Plot feature importance for an XGBoost model}
\usage{
tl_plot_xgboost_importance(model, top_n = 10, importance_type = "gain", ...)
}
\arguments{
\item{model}{A tidylearn XGBoost model object}

\item{top_n}{Number of top features to display (default: 10)}

\item{importance_type}{Type of importance: "gain", "cover", "frequency"}

\item{...}{Additional arguments}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot feature importance for an XGBoost model
}
\examples{
\donttest{
if (requireNamespace("xgboost", quietly = TRUE)) {
  model <- tl_model(mtcars, mpg ~ ., method = "xgboost")
  tl_plot_xgboost_importance(model)
}
}
}
