% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-neural-networks.R
\name{tidylearn-neural-networks}
\alias{tidylearn-neural-networks}
\title{Neural Networks for tidylearn}
\description{
Neural network functionality for classification and regression
}
