% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read.R
\name{print.tidylearn_data}
\alias{print.tidylearn_data}
\title{Print a tidylearn_data object}
\usage{
\method{print}{tidylearn_data}(x, ...)
}
\arguments{
\item{x}{A \code{tidylearn_data} object.}

\item{...}{Additional arguments passed to the tibble print method.}
}
\value{
The input object \code{x}, returned invisibly.
}
\description{
Print a tidylearn_data object
}
\examples{
\donttest{
f <- tempfile(fileext = ".csv")
write.csv(iris, f, row.names = FALSE)
d <- tl_read(f)
print(d)
}
}
