% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-hclust.R
\name{tidy_dendrogram}
\alias{tidy_dendrogram}
\title{Plot Dendrogram}
\usage{
tidy_dendrogram(hclust_obj, k = NULL, hang = 0.01, cex = 0.7)
}
\arguments{
\item{hclust_obj}{A tidy_hclust object or hclust object}

\item{k}{Optional; number of clusters to highlight with rectangles}

\item{hang}{Fraction of plot height to hang labels (default: 0.01)}

\item{cex}{Label size (default: 0.7)}
}
\value{
The \code{\link[stats]{hclust}} object, returned invisibly. The
dendrogram is plotted as a side effect.
}
\description{
Create dendrogram visualization
}
\examples{
\donttest{
hc <- tidy_hclust(USArrests, method = "ward.D2")
tidy_dendrogram(hc, k = 3)
}

}
