% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pipeline.R
\name{tl_compare_pipeline_models}
\alias{tl_compare_pipeline_models}
\title{Compare models from a pipeline}
\usage{
tl_compare_pipeline_models(pipeline, metrics = NULL)
}
\arguments{
\item{pipeline}{A tidylearn pipeline object with results}

\item{metrics}{Character vector of metrics to compare
(if NULL, uses all available)}
}
\value{
A \code{\link[ggplot2]{ggplot}} object showing a faceted bar
chart comparing metric values across models, with the best model
highlighted.
}
\description{
Compare models from a pipeline
}
