% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-svm.R
\name{tl_plot_svm_boundary}
\alias{tl_plot_svm_boundary}
\title{Plot SVM decision boundary}
\usage{
tl_plot_svm_boundary(model, x_var = NULL, y_var = NULL, grid_size = 100, ...)
}
\arguments{
\item{model}{A tidylearn SVM model object}

\item{x_var}{Name of the x-axis variable}

\item{y_var}{Name of the y-axis variable}

\item{grid_size}{Number of points in each dimension
for the grid (default: 100)}

\item{...}{Additional arguments}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot SVM decision boundary
}
\examples{
\donttest{
if (requireNamespace("e1071", quietly = TRUE)) {
  model <- tl_model(iris, Species ~ ., method = "svm")
  tl_plot_svm_boundary(model,
    x_var = "Sepal.Length", y_var = "Sepal.Width")
}
}
}
