% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pipeline.R
\name{tl_load_pipeline}
\alias{tl_load_pipeline}
\title{Load a pipeline from disk}
\usage{
tl_load_pipeline(file)
}
\arguments{
\item{file}{Path to the pipeline file}
}
\value{
A \code{tidylearn_pipeline} object previously saved with
\code{\link{tl_save_pipeline}}.
}
\description{
Load a pipeline from disk
}
\examples{
\donttest{
pipe <- tl_pipeline(iris, Species ~ .)
f <- tempfile(fileext = ".rds")
tl_save_pipeline(pipe, f)
pipe2 <- tl_load_pipeline(f)
}
}
