% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{predict.tidylearn_stratified}
\alias{predict.tidylearn_stratified}
\title{Predict from stratified models}
\usage{
\method{predict}{tidylearn_stratified}(object, new_data = NULL, ...)
}
\arguments{
\item{object}{A tidylearn_stratified model object}

\item{new_data}{New data for predictions}

\item{...}{Additional arguments}
}
\value{
A \link[tibble]{tibble} with a \code{.pred} column containing
predictions and a \code{.cluster} column with cluster assignments.
}
\description{
Predict from stratified models
}
\examples{
\donttest{
models <- tl_stratified_models(mtcars, mpg ~ .,
  cluster_method = "kmeans", k = 2, supervised_method = "linear")
preds <- predict(models)
}
}
