% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-svm.R
\name{tl_plot_svm_tuning}
\alias{tl_plot_svm_tuning}
\title{Plot SVM tuning results}
\usage{
tl_plot_svm_tuning(model, ...)
}
\arguments{
\item{model}{A tidylearn SVM model object}

\item{...}{Additional arguments}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot SVM tuning results
}
\examples{
\donttest{
if (requireNamespace("e1071", quietly = TRUE)) {
  model <- tl_model(iris, Species ~ ., method = "svm",
    kernel = "linear", tune = TRUE, tune_folds = 2)
  tl_plot_svm_tuning(model)
}
}
}
