% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-xgboost.R
\name{tl_predict_xgboost}
\alias{tl_predict_xgboost}
\title{Predict using an XGBoost model}
\usage{
tl_predict_xgboost(model, new_data, type = "response", ntreelimit = NULL, ...)
}
\arguments{
\item{model}{A tidylearn XGBoost model object}

\item{new_data}{A data frame containing the new data}

\item{type}{Type of prediction: "response" (default),
"prob" (for classification), "class" (for classification)}

\item{ntreelimit}{Limit number of trees used for prediction
(default: NULL, uses all trees)}

\item{...}{Additional arguments}
}
\value{
Predictions
}
\description{
Predict using an XGBoost model
}
\keyword{internal}
