% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-dbscan.R
\name{print.tidy_dbscan}
\alias{print.tidy_dbscan}
\title{Print Method for tidy_dbscan}
\usage{
\method{print}{tidy_dbscan}(x, ...)
}
\arguments{
\item{x}{A tidy_dbscan object}

\item{...}{Additional arguments (ignored)}
}
\value{
The input object \code{x}, returned invisibly.
}
\description{
Print Method for tidy_dbscan
}
\examples{
\donttest{
db <- tidy_dbscan(iris[, 1:4], eps = 0.5, minPts = 5)
print(db)
}

}
