% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-deep-learning.R
\name{tidylearn-deep-learning}
\alias{tidylearn-deep-learning}
\title{Deep Learning for tidylearn}
\description{
Deep learning functionality using Keras/TensorFlow
}
