% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-regularization.R
\name{tl_predict_ridge}
\alias{tl_predict_ridge}
\title{Predict using a Ridge regression model}
\usage{
tl_predict_ridge(model, new_data, type = "response", ...)
}
\arguments{
\item{model}{A tidylearn Ridge model object}

\item{new_data}{A data frame containing the new data}

\item{type}{Type of prediction}

\item{...}{Additional arguments}
}
\value{
Predictions
}
\description{
Predict using a Ridge regression model
}
\keyword{internal}
