% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core.R
\name{summary.tidylearn_model}
\alias{summary.tidylearn_model}
\title{Summary method for tidylearn models}
\usage{
\method{summary}{tidylearn_model}(object, ...)
}
\arguments{
\item{object}{A tidylearn model object}

\item{...}{Additional arguments (ignored)}
}
\value{
The input \code{object}, returned invisibly. Called for its
side effect of printing model summary and training performance.
}
\description{
Summary method for tidylearn models
}
\examples{
\donttest{
model <- tl_model(mtcars, mpg ~ wt + hp, method = "linear")
summary(model)
}
}
