% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-xgboost.R
\name{tl_plot_xgboost_tree}
\alias{tl_plot_xgboost_tree}
\title{Plot XGBoost tree visualization}
\usage{
tl_plot_xgboost_tree(model, tree_index = 0, ...)
}
\arguments{
\item{model}{A tidylearn XGBoost model object}

\item{tree_index}{Index of the tree to plot (default: 0, first tree)}

\item{...}{Additional arguments}
}
\value{
The return value of \code{\link[xgboost]{xgb.plot.tree}}, a
tree diagram rendered via the \pkg{DiagrammeR} package.
}
\description{
Plot XGBoost tree visualization
}
