% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualization.R
\name{tl_get_importance_regularized}
\alias{tl_get_importance_regularized}
\title{Extract importance from a regularized regression model}
\usage{
tl_get_importance_regularized(model, lambda = "1se")
}
\arguments{
\item{model}{A tidylearn regularized model object}

\item{lambda}{Which lambda to use ("1se" or "min", default: "1se")}
}
\value{
A data frame with feature importance values
}
\description{
Extract importance from a regularized regression model
}
\keyword{internal}
