% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/workflows.R
\name{predict.tidylearn_transfer}
\alias{predict.tidylearn_transfer}
\title{Predict with transfer learning model}
\usage{
\method{predict}{tidylearn_transfer}(object, new_data, ...)
}
\arguments{
\item{object}{A tidylearn_transfer model object}

\item{new_data}{New data for predictions}

\item{...}{Additional arguments}
}
\value{
A \link[tibble]{tibble} with a \code{.pred} column containing
predictions.
}
\description{
Predict with transfer learning model
}
\examples{
\donttest{
model <- tl_transfer_learning(iris, Species ~ .,
  pretrain_method = "pca", supervised_method = "logistic")
preds <- predict(model, iris[1:5, ])
}
}
