% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-clustering.R
\name{augment_pam}
\alias{augment_pam}
\title{Augment Data with PAM Cluster Assignments}
\usage{
augment_pam(pam_obj, data)
}
\arguments{
\item{pam_obj}{A tidy_pam object}

\item{data}{Original data frame}
}
\value{
A tibble containing the original \code{data} with an additional
\code{cluster} factor column indicating cluster assignments.
}
\description{
Augment Data with PAM Cluster Assignments
}
\examples{
\donttest{
pm <- tidy_pam(iris[, 1:4], k = 3)
augmented <- augment_pam(pm, iris)
}

}
