% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualization.R
\name{tl_dashboard}
\alias{tl_dashboard}
\title{Create interactive visualization dashboard for a model}
\usage{
tl_dashboard(model, new_data = NULL, ...)
}
\arguments{
\item{model}{A tidylearn model object}

\item{new_data}{Optional data frame for evaluation
(if NULL, uses training data)}

\item{...}{Additional arguments}
}
\value{
A \code{\link[shiny]{shinyApp}} object.
}
\description{
Create interactive visualization dashboard for a model
}
\examples{
\donttest{
if (requireNamespace("shiny")) {
  model <- tl_model(mtcars, mpg ~ wt + hp, method = "linear")
  app <- tl_dashboard(model)
}
}
}
