% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-regression.R
\name{tl_plot_intervals}
\alias{tl_plot_intervals}
\title{Create confidence and prediction interval plots}
\usage{
tl_plot_intervals(model, new_data = NULL, level = 0.95, ...)
}
\arguments{
\item{model}{A tidylearn regression model object}

\item{new_data}{Optional data frame for prediction
(if NULL, uses training data)}

\item{level}{Confidence level (default: 0.95)}

\item{...}{Additional arguments}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Create confidence and prediction interval plots
}
\examples{
\donttest{
model <- tl_model(mtcars, mpg ~ wt, method = "linear")
tl_plot_intervals(model)
}
}
