% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-regularization.R
\name{tl_predict_regularized}
\alias{tl_predict_regularized}
\title{Predict using a regularized regression model}
\usage{
tl_predict_regularized(model, new_data, type = "response", lambda = "1se", ...)
}
\arguments{
\item{model}{A tidylearn regularized model object}

\item{new_data}{A data frame containing the new data}

\item{type}{Type of prediction: "response" (default),
"class" or "prob" (for classification)}

\item{lambda}{Which lambda to use for prediction
("1se" or "min", default: "1se")}

\item{...}{Additional arguments}
}
\value{
Predictions
}
\description{
Predict using a regularized regression model
}
\keyword{internal}
