% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-hclust.R
\name{augment_hclust}
\alias{augment_hclust}
\title{Augment Data with Hierarchical Cluster Assignments}
\usage{
augment_hclust(hclust_obj, data, k = NULL, h = NULL)
}
\arguments{
\item{hclust_obj}{A tidy_hclust object}

\item{data}{Original data frame}

\item{k}{Number of clusters (optional)}

\item{h}{Height at which to cut (optional)}
}
\value{
A tibble containing the original \code{data} with an additional
\code{cluster} integer column indicating cluster assignments.
}
\description{
Add cluster assignments to original data
}
\examples{
\donttest{
hc <- tidy_hclust(USArrests, method = "ward.D2")
augmented <- augment_hclust(hc, USArrests, k = 3)
}

}
