% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-trees.R
\name{tl_plot_partial_dependence}
\alias{tl_plot_partial_dependence}
\title{Plot partial dependence for tree-based models}
\usage{
tl_plot_partial_dependence(model, var, n.pts = 20, ...)
}
\arguments{
\item{model}{A tidylearn tree-based model object}

\item{var}{Variable name to plot}

\item{n.pts}{Number of points for continuous
variables (default: 20)}

\item{...}{Additional arguments}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot partial dependence for tree-based models
}
\examples{
\donttest{
model <- tl_model(mtcars, mpg ~ ., method = "forest")
tl_plot_partial_dependence(model, var = "wt")
}
}
