% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualization.R
\name{tl_plot_lift}
\alias{tl_plot_lift}
\title{Plot lift chart for a classification model}
\usage{
tl_plot_lift(model, new_data = NULL, bins = 10, ...)
}
\arguments{
\item{model}{A tidylearn classification model object}

\item{new_data}{Optional data frame for evaluation
(if NULL, uses training data)}

\item{bins}{Number of bins for grouping predictions
(default: 10)}

\item{...}{Additional arguments}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot lift chart for a classification model
}
\examples{
\donttest{
iris_bin <- iris[iris$Species != "setosa", ]
iris_bin$Species <- factor(iris_bin$Species)
model <- tl_model(iris_bin, Species ~ ., method = "logistic")
tl_plot_lift(model)
}
}
