% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metrics.R
\name{tidylearn-metrics}
\alias{tidylearn-metrics}
\title{Metrics Functionality for tidylearn}
\description{
Functions for calculating model evaluation metrics
}
