% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-pca.R
\name{get_pca_loadings}
\alias{get_pca_loadings}
\title{Get PCA Loadings in Wide Format}
\usage{
get_pca_loadings(pca_obj, n_components = NULL)
}
\arguments{
\item{pca_obj}{A tidy_pca object}

\item{n_components}{Number of components to include (default: all)}
}
\value{
A tibble with one row per variable and one column per principal
component, containing the loading values.
}
\description{
Get PCA Loadings in Wide Format
}
\examples{
\donttest{
pca <- tidy_pca(USArrests)
get_pca_loadings(pca, n_components = 2)
}

}
