% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/interactions.R
\name{tl_plot_interaction}
\alias{tl_plot_interaction}
\title{Plot interaction effects}
\usage{
tl_plot_interaction(
  model,
  var1,
  var2,
  n_points = 100,
  fixed_values = NULL,
  confidence = TRUE,
  ...
)
}
\arguments{
\item{model}{A tidylearn model object}

\item{var1}{First variable in the interaction}

\item{var2}{Second variable in the interaction}

\item{n_points}{Number of points to use for continuous variables}

\item{fixed_values}{Named list of values for other variables in the model}

\item{confidence}{Logical; whether to show confidence intervals}

\item{...}{Additional arguments to pass to predict()}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot interaction effects
}
