% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-deep-learning.R
\name{tl_plot_deep_history}
\alias{tl_plot_deep_history}
\title{Plot deep learning model training history}
\usage{
tl_plot_deep_history(model, metrics = c("loss", "val_loss"), ...)
}
\arguments{
\item{model}{A tidylearn deep learning model object}

\item{metrics}{Which metrics to plot
(default: c("loss", "val_loss"))}

\item{...}{Additional arguments}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot deep learning model training history
}
\examples{
\dontrun{
if (requireNamespace("keras", quietly = TRUE)) {
  model <- tl_model(iris, Species ~ ., method = "deep", epochs = 5)
  tl_plot_deep_history(model)
}
}
}
