% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-validation.R
\name{print.tidy_silhouette}
\alias{print.tidy_silhouette}
\title{Print Method for tidy_silhouette}
\usage{
\method{print}{tidy_silhouette}(x, ...)
}
\arguments{
\item{x}{A tidy_silhouette object}

\item{...}{Additional arguments (ignored)}
}
\value{
The input object \code{x}, returned invisibly.
}
\description{
Print Method for tidy_silhouette
}
\examples{
\donttest{
km <- kmeans(iris[, 1:4], centers = 3, nstart = 25)
d <- dist(iris[, 1:4])
sil <- tidy_silhouette(km$cluster, d)
print(sil)
}

}
