% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-validation.R
\name{plot_gap_stat}
\alias{plot_gap_stat}
\title{Plot Gap Statistic}
\usage{
plot_gap_stat(gap_obj, show_methods = FALSE)
}
\arguments{
\item{gap_obj}{A tidy_gap object}

\item{show_methods}{Logical; show all three k
selection methods? (default: FALSE)}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Plot Gap Statistic
}
\examples{
\donttest{
gap <- tidy_gap_stat(iris[, 1:4], max_k = 6, B = 10)
plot_gap_stat(gap)
}

}
