% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core.R
\name{plot.tidylearn_model}
\alias{plot.tidylearn_model}
\title{Plot method for tidylearn models}
\usage{
\method{plot}{tidylearn_model}(x, type = "auto", ...)
}
\arguments{
\item{x}{A tidylearn model object}

\item{type}{Plot type (default: "auto")}

\item{...}{Additional arguments passed to plotting functions}
}
\value{
A \code{\link[ggplot2]{ggplot}} object. The specific plot depends
on the model paradigm and \code{type} argument.
}
\description{
Plot method for tidylearn models
}
\examples{
\donttest{
model <- tl_model(mtcars, mpg ~ wt + hp, method = "linear")
plot(model, type = "actual_predicted")
}
}
