% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/workflows.R
\name{plot.tidylearn_eda}
\alias{plot.tidylearn_eda}
\title{Plot EDA results}
\usage{
\method{plot}{tidylearn_eda}(x, ...)
}
\arguments{
\item{x}{A tidylearn_eda object}

\item{...}{Additional arguments (ignored)}
}
\value{
The input object \code{x}, returned invisibly. Called for its
side effect of plotting a PCA scatter plot coloured by cluster.
}
\description{
Plot EDA results
}
\examples{
\donttest{
eda <- tl_explore(iris, response = "Species")
plot(eda)
}
}
