% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualization.R
\name{plot_cluster_comparison}
\alias{plot_cluster_comparison}
\title{Create Cluster Comparison Plot}
\usage{
plot_cluster_comparison(data, cluster_cols, x_col, y_col)
}
\arguments{
\item{data}{Data frame with multiple cluster columns}

\item{cluster_cols}{Vector of cluster column names}

\item{x_col}{X-axis variable}

\item{y_col}{Y-axis variable}
}
\value{
The return value of \code{\link[gridExtra]{grid.arrange}}, a
\code{\link[gtable]{gtable}} drawn as a side effect.
}
\description{
Compare multiple clustering results side-by-side
}
\examples{
\donttest{
df <- iris[, 1:4]
df$km3 <- kmeans(df, 3)$cluster
df$km4 <- kmeans(df, 4)$cluster
plot_cluster_comparison(df, c("km3", "km4"), "Sepal.Length", "Sepal.Width")
}
}
