% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/workflows.R
\name{print.tidylearn_automl}
\alias{print.tidylearn_automl}
\title{Print auto ML results}
\usage{
\method{print}{tidylearn_automl}(x, ...)
}
\arguments{
\item{x}{A tidylearn_automl object}

\item{...}{Additional arguments (ignored)}
}
\value{
The input object \code{x}, returned invisibly.
}
\description{
Print auto ML results
}
