% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-neural-networks.R
\name{tl_predict_nn}
\alias{tl_predict_nn}
\title{Predict using a neural network model}
\usage{
tl_predict_nn(model, new_data, type = "response", ...)
}
\arguments{
\item{model}{A tidylearn neural network model object}

\item{new_data}{A data frame containing the new data}

\item{type}{Type of prediction: "response" (default),
"prob" (for classification), "class" (for classification)}

\item{...}{Additional arguments}
}
\value{
Predictions
}
\description{
Predict using a neural network model
}
\keyword{internal}
