% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metrics.R
\name{tl_evaluate}
\alias{tl_evaluate}
\title{Evaluate a tidylearn model}
\usage{
tl_evaluate(object, new_data = NULL, ...)
}
\arguments{
\item{object}{A tidylearn model object}

\item{new_data}{Optional new data for evaluation
(if NULL, uses training data)}

\item{...}{Additional arguments}
}
\value{
A \link[tibble]{tibble} with columns \code{metric} (character)
and \code{value} (numeric). For regression models, includes
\code{rmse}, \code{mae}, and \code{rsq}. For classification models,
includes \code{accuracy}.
}
\description{
Evaluate a tidylearn model
}
\examples{
\donttest{
model <- tl_model(mtcars, mpg ~ wt + hp, method = "linear")
tl_evaluate(model)
}
}
