% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-regularization.R
\name{tl_plot_regularization_cv}
\alias{tl_plot_regularization_cv}
\title{Plot cross-validation results for a regularized model}
\usage{
tl_plot_regularization_cv(model, ...)
}
\arguments{
\item{model}{A tidylearn regularized model object
(ridge, lasso, or elastic_net)}

\item{...}{Additional arguments (currently unused)}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Shows the cross-validation error as a function of
lambda for ridge, lasso, or elastic net models fitted
with cv.glmnet.
}
\examples{
\donttest{
model <- tl_model(mtcars, mpg ~ ., method = "ridge")
tl_plot_regularization_cv(model)
}
}
