% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supervised-trees.R
\name{tidylearn-trees}
\alias{tidylearn-trees}
\title{Tree-based Methods for tidylearn}
\description{
Decision trees, random forests, and boosting functionality
}
