% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unsupervised-market-basket.R
\name{tidy_rules}
\alias{tidy_rules}
\title{Convert Association Rules to Tidy Tibble}
\usage{
tidy_rules(rules)
}
\arguments{
\item{rules}{A rules object from arules}
}
\value{
A tibble with columns \code{rule_id}, \code{lhs}, \code{rhs}, and
quality measures (e.g., \code{support}, \code{confidence}, \code{lift}).
}
\description{
Convert Association Rules to Tidy Tibble
}
\examples{
\donttest{
if (requireNamespace("arules", quietly = TRUE)) {
  data("Groceries", package = "arules")
  rules_obj <- arules::apriori(Groceries,
    parameter = list(supp = 0.001, conf = 0.5))
  rules_tbl <- tidy_rules(rules_obj)
}
}

}
